[Jifty-commit] r5559 - in jifty/trunk: lib/Jifty lib/Jifty/Action/Record t/TestApp/lib/TestApp/Action

Jifty commits jifty-commit at lists.jifty.org
Sun Jul 20 23:17:20 EDT 2008


Author: sterling
Date: Sun Jul 20 23:17:19 2008
New Revision: 5559

Modified:
   jifty/trunk/   (props changed)
   jifty/trunk/lib/Jifty/Action/Record/Execute.pm
   jifty/trunk/lib/Jifty/ClassLoader.pm
   jifty/trunk/lib/Jifty/Record.pm
   jifty/trunk/t/TestApp/lib/TestApp/Action/PassSomething.pm

Log:
 r98264 at shanenka-lt-osx:  shanenka | 2008-07-20 21:00:22 -0500
 Finished renaming Do to Execute and added ClassLoader helps.


Modified: jifty/trunk/lib/Jifty/Action/Record/Execute.pm
==============================================================================
--- jifty/trunk/lib/Jifty/Action/Record/Execute.pm	(original)
+++ jifty/trunk/lib/Jifty/Action/Record/Execute.pm	Sun Jul 20 23:17:19 2008
@@ -1,14 +1,14 @@
 use warnings;
 use strict;
 
-package Jifty::Action::Record::Do;
+package Jifty::Action::Record::Execute;
 use base qw/ Jifty::Action::Record /;
 
 use Hash::Merge;
 
 =head1 NAME
 
-Jifty::Action::Record::Do - Simple abstract based for record actions
+Jifty::Action::Record::Execute - Simple abstract based for record actions
 
 =head1 SYNOPSIS
 
@@ -16,7 +16,7 @@
   use warnings;
 
   package MyApp::Action::StartEncabulator;
-  use base qw/ MyApp::Action::DoEncabulator /;
+  use base qw/ MyApp::Action::ExecuteEncabulator /;
 
   use Jifty::Param::Schema;
   use Jifty::Action schema {

Modified: jifty/trunk/lib/Jifty/ClassLoader.pm
==============================================================================
--- jifty/trunk/lib/Jifty/Record.pm	(original)
+++ jifty/trunk/lib/Jifty/Record.pm	Sun Jul 20 23:17:19 2008
@@ -874,7 +874,7 @@
 
 Controls which of the L<Jifty::Action::Record> subclasses are
 automatically set up for this model; this subroutine is passed one of
-the strings C<Create>, C<Update>, C<Delete> or C<Search>, and should
+the strings C<Create>, C<Update>, C<Delete>, C<Search> or C<Execute>, and should
 return a true value if that action should be autogenerated.
 
 The default method returns 0 for all action classes if the model is

Modified: jifty/trunk/t/TestApp/lib/TestApp/Action/PassSomething.pm
==============================================================================
--- jifty/trunk/t/TestApp/lib/TestApp/Action/PassSomething.pm	(original)
+++ jifty/trunk/t/TestApp/lib/TestApp/Action/PassSomething.pm	Sun Jul 20 23:17:19 2008
@@ -2,7 +2,7 @@
 use warnings;
 
 package TestApp::Action::PassSomething;
-use base qw/ Jifty::Action::Record::Do /;
+use base qw/ TestApp::Action::ExecuteSomething /;
 
 use Test::More ();
 


More information about the Jifty-commit mailing list
--- jifty/trunk/lib/Jifty/ClassLoader.pm	(original)
+++ jifty/trunk/lib/Jifty/ClassLoader.pm	Sun Jul 20 23:17:19 2008
@@ -67,7 +67,7 @@
 
 =item I<Application>::Action::I<[Verb]>I<[Something]>
 
-If I<Application>::Model::I<Something> is a valid model class and I<Verb> is one of "Create", "Search", "Update", or "Delete", then it creates a subclass of I<Application>::Action::Record::I<Verb>  Models can control which actions are generated by overriding L<Jifty::Record/autogenerate_action>.  See also L<Jifty::Record/is_private> and L<Jifty::Record/is_protected>.
+If I<Application>::Model::I<Something> is a valid model class and I<Verb> is one of "Create", "Search", "Update", "Execute", or "Delete", then it creates a subclass of I<Application>::Action::Record::I<Verb>  Models can control which actions are generated by overriding L<Jifty::Record/autogenerate_action>.  See also L<Jifty::Record/is_private> and L<Jifty::Record/is_protected>.
 
 =item I<Application>::Action::I<Something>
 
@@ -77,7 +77,7 @@
 
 =item I<Application>::Action::Record::I<Something>
 
-An empty class that descends from the matching Jifty class, Jifty::Action::Record::I<Something>. This is generally used to build application-specific descendants of L<Jifty::Action::Record::Create>, L<Jifty::Action::Record::Search>, L<Jifty::Action::Record::Update>, or L<Jifty::Action::Record::Delete>.
+An empty class that descends from the matching Jifty class, Jifty::Action::Record::I<Something>. This is generally used to build application-specific descendants of L<Jifty::Action::Record::Create>, L<Jifty::Action::Record::Execute>, L<Jifty::Action::Record::Search>, L<Jifty::Action::Record::Update>, or L<Jifty::Action::Record::Delete>.
 
 =item I<Application>::Bootstrap
 
@@ -218,7 +218,7 @@
     
     # Autogenerate the record actions for a model
     elsif ( $module =~ /^(?:$base)::Action::
-                        (Create|Update|Delete|Search)([^\.]+)$/x ) {
+                        (Create|Update|Delete|Search|Execute)([^\.]+)$/x ) {
 
         my $action = $1;
         my $model  = $2;
@@ -264,9 +264,9 @@
     # it's place.
 
     # N.B. This is if and not elsif on purpose. If the class name requested is
     # App::Action::(Create|Update|Search|Delete)Thing, but there is no such
     # model as App::Model::Thing, we may be trying to create a sub-class of
-    # Plugin::Action::(Create|Update|Search|Delete)Thing for
+    # Plugin::Action::(Create|Update|Search|Delete|Execute)Thing for
     # Plugin::Model::Thing instead.
     
     # Requesting an application override of a plugin action or notification?
@@ -382,7 +382,7 @@
     my($short) = $full =~ /::Model::(\w*)/;
     Jifty::Util->require($full . "Collection");
     Jifty::Util->require($base . "::Action::" . $_ . $short)
-        for grep {$full->autogenerate_action($_)} qw/Create Update Delete Search/;
+        for grep {$full->autogenerate_action($_)} qw/Create Update Delete Search Execute/;
 }
 
 
@@ -264,9 +264,9 @@
 
     # N.B. This is if and not elsif on purpose. If the class name requested is
-    # App::Action::(Create|Update|Search|Delete)Thing, but there is no such
+    # App::Action::(Create|Update|Search|Delete|Execute)Thing, but there is no such
     # model as App::Model::Thing, we may be trying to create a sub-class of

Modified: jifty/trunk/lib/Jifty/Record.pm
==============================================================================